@@ -66,7 +66,7 @@ class Client:
                 raise Exception(error_code)
 
         for raw_data in raw_res:
-            data = yaml.load(raw_data.get_field('data').decode("utf-8"))
+            data = yaml.safe_load(raw_data.get_field('data').decode("utf-8"))
             res.append(data)
         return res
 
